aboutsummaryrefslogtreecommitdiffstats
path: root/indent.sh
diff options
context:
space:
mode:
Diffstat (limited to 'indent.sh')
-rwxr-xr-xindent.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/indent.sh b/indent.sh
index 1c96e11..9885e49 100755
--- a/indent.sh
+++ b/indent.sh
@@ -1,8 +1,8 @@
#! /bin/bash
# -kr Use Kernighan & Ritchie coding style.
# -l150 Set maximum line length for non-comment lines to 150.
# -pmt Preserve access and modification times on output files.
-indent -kr -l150 -pmt *.c *.h
+indent -kr -l120 -pmt *.c *.h
@@ -1,8 +1,8 @@
#! /bin/bash
# -kr Use Kernighan & Ritchie coding style.
-# -l150 Set maximum line length for non-comment lines to 150.
+# -l120 Set maximum line length for non-comment lines to 150.
# -pmt Preserve access and modification times on output files.